@@ -108,7 +108,7 @@ class Link < InLineElement
 		self.label = label;
 	end
 
-	attr "label", true
+	attr :label, true
 
 	def accept(visitor)
 		visitor.visit_link(self);
@@ -129,7 +129,7 @@ class URILink < Link
 		self.uri = uri;
 	end
 
-	attr "uri", true
+	attr :uri, true
 
 	def accept(visitor)
 		visitor.visit_uri_link(self);
@@ -140,12 +140,35 @@ class URILink < Link
 	end
 end
 
+class InterLink < Link
+	def initialize(label, prefix)
+		super(label);
+		self.prefix = prefix;
+	end
+
+	attr :prefix, true
+
+	def accept(visitor)
+		visitor.visit_inter_link(self);
+	end
+
+	def ==(other)
+		(self.class == other.class) and 
+		(self.label == other.label) and 
+		(self.prefix == other.prefix)
+	end
+
+	def to_s
+		self.prefix + ':' + self.label
+	end
+end
+
 class Text < InLineElement
 	def initialize(text = '')
 		self.text = text
 	end
 
-	attr "text", false
+	attr :text, false
 
 	def accept(visitor)
 		visitor.visit_text(self);
@@ -160,7 +183,7 @@ class Text < InLineElement
 	end
 
 protected
-	attr_writer "text"
+	attr_writer :text
 end
 
 class ListElement < Element
@@ -210,7 +233,7 @@ class DefinitionItem < Element
 			self.append_child(description);
 		end
 	end
-	attr "term", true
+	attr :term, true
 
 	def accept(visitor)
 		visitor.visit_definition_item(self);
@@ -310,7 +333,7 @@ class Headline < Element
 		super(child)
 		@level = level
 	end
-	attr "level", false
+	attr :level, false
 
 	def accept(visitor)
 		visitor.visit_headline(self);
