@@ -29,7 +29,9 @@ class FilePageDataSource < PageDataSource
 		page_source = nil
 		source_file_path = make_source_file_path(page_name, lang, version)
 		File.open(source_file_path, "r+") do |source_file|
-			source_file.flock(File::LOCK_EX) 
+			until source_file.flock(File::LOCK_SH|File::LOCK_NB) do
+				sleep 0.01
+			end
 			page_source = source_file.readlines.to_s
 		end
 		page_source
@@ -40,7 +42,9 @@ class FilePageDataSource < PageDataSource
 		create_page(page_name, lang, version)
 
 		File.open(source_file_path, "w+"){ |source_file|
-			source_file.flock(File::LOCK_EX) 
+			until source_file.flock(File::LOCK_EX|File::LOCK_NB) do
+				sleep 0.01
+			end
 			source_file.write(source)
 		}
 
@@ -151,7 +155,9 @@ protected
 
 		unless File.file?(source_file_path) then
 			File.open(source_file_path, "w+"){ |source_file|
-				source_file.flock(File::LOCK_EX) 
+				until source_file.flock(File::LOCK_EX|File::LOCK_NB) do
+					sleep 0.01
+				end
 				source_file.write("\n")
 			}
 		end
@@ -162,7 +168,9 @@ protected
 			property['page_title'] = page_name
 			property['language'] = lang
 			File.open(property_file_path, "w+"){ |prop_file|
-				prop_file.flock(File::LOCK_EX) 
+				until prop_file.flock(File::LOCK_EX|File::LOCK_NB) do
+					sleep 0.01
+				end
 				PropertyFile.write_property(prop_file, property)
 			}
 		end
@@ -175,7 +183,9 @@ protected
 				File.readable?(cache_file_path) then
 			begin
 				File.open(cache_file_path, "r+") do |cache_file|
-					cache_file.flock(File::LOCK_EX) 
+					until cache_file.flock(File::LOCK_EX|File::LOCK_NB) do
+						sleep 0.01
+					end
 					document =  Marshal.restore(cache_file)
 				end
 			rescue NameError, TypeError, EOFError
@@ -188,7 +198,9 @@ protected
 	def save_cached_document(page_name, lang, version, document)
 		cache_file_path = make_cache_file_path(page_name, lang, version)
 		File.open(cache_file_path, "w+"){ |cache_file|
-			cache_file.flock(File::LOCK_EX) 
+			until cache_file.flock(File::LOCK_EX|File::LOCK_NB) do
+				sleep 0.01
+			end
 			Marshal.dump(document, cache_file);
 		}
 
