@@ -46,7 +46,6 @@ class KakiRequestHandler
 		@script_path = nil
 		@server_uri = nil
 		@remote_address = nil
-		@site_property = nil
 
 		@theme_base_url = nil
 		@theme_dir = nil
@@ -264,6 +263,7 @@ protected
 		unless @wiki2html then
 			@wiki2html = Wiki::ToWikiHtml.new(self.page_data_source, '')
 			@wiki2html.xhtml = true;
+			@wiki2html.language_list = self.request_language_list
 		end
 		@wiki2html
 	end
@@ -285,10 +285,10 @@ protected
 		page_name, page_lang, page_version = self.page_data_source.parse_page_id(page_id)
 		wiki_doc = self.page_data_source.load_page_document(page_name, page_lang, page_version)
 		if wiki_doc then
+
 			self.wiki2html.output = ''
 			self.wiki2html.link_base_uri = "#{self.script_path}?p="
-#			self.wiki2html.default_lang_list = self.request_language_list
-			self.wiki2html.default_lang_list = nil
+			self.wiki2html.page_language = page_lang
 			wiki_doc.accept(self.wiki2html)
 			data[:content] = self.wiki2html.output 
 			self.page_data_source.page_property(page_name, page_lang, page_version){ |property|
@@ -457,9 +457,7 @@ protected
 		if wiki_doc then
 			self.wiki2html.output = ''
 			self.wiki2html.link_base_uri = "#{self.script_path}?p="
-#			self.wiki2html.default_lang_list = [page_lang] + self.request_language_list
-#			self.wiki2html.default_lang_list = self.request_language_list
-			self.wiki2html.default_lang_list = nil
+			self.wiki2html.page_language = page_lang
 			wiki_doc.accept(self.wiki2html)
 			data[:content] = self.wiki2html.output 
 		else
@@ -792,14 +790,15 @@ protected
 					if new_passwd1 == new_passwd2 then
 						salt = [[rand(4096)].pack("v")].pack("m").tr("+", ".")
 						property['admin_passwd'] = new_passwd1.crypt(salt)
+						data[:admin_passwd_change_ok] = true
 					else
 						data[:new_passwd_miss_match] = true
 					end
 				else
 					property['admin_passwd'] = nil
+					data[:admin_passwd_change_ok] = true
 				end
 				self.site_property = property
-				data[:admin_passwd_change_ok] = true
 			else
 				data[:admin_auth_fail_msg] = true
 			end
@@ -1229,13 +1228,16 @@ protected
 			if sub_page_doc then
 				self.wiki2html.output = ''
 				self.wiki2html.link_base_uri = "#{self.script_path}?p="
-				self.wiki2html.default_lang_list = self.request_language_list
+				self.wiki2html.page_language = sub_page_lang
+				self.wiki2html.sub_page_mode = true
 				sub_page_doc.accept(self.wiki2html)
 				result = self.wiki2html.output
 			end
 		end
 		return result;
 	end
+
+
 end
 
 
