@@ -33,8 +33,8 @@ class TemplateDataSource
 	end
 
 protected
-	attr "root_dir", true
-	attr "cache_table", true
+	attr :root_dir, true
+	attr :cache_table, true
 
 end
 
