@@ -4,13 +4,19 @@ require 'cgi'
 require 'uri'
 require 'base64'
 
+require 'InterWikiNameAnalyzer.rb'
+
+
 class ToHtml
-	attr "xhtml", true;
-	attr "output", true;
+	attr :xhtml, true;
+	attr :output, true;
+	attr :inter_wiki_name_document, true;
 
 	def initialize(output = STDOUT)
 		self.output = output;
 		self.xhtml = false;
+		self.inter_wiki_name_document = nil;
+		@inter_wiki_name_table = nil
 	end
 
 	def visit_emphasis(element)
@@ -54,6 +60,18 @@ class ToHtml
 		output << str
 	end
 
+	def visit_inter_link(element)
+		prefix_uri = nil
+		if self.inter_wiki_name_table[element.prefix] then
+			prefix_uri = self.inter_wiki_name_table[element.prefix]
+		end
+		if prefix_uri then
+			output << %Q!<a href="#{prefix_uri}#{URI::escape(element.label)}">#{CGI.escapeHTML(element.to_s)}</a>!
+		else
+			self.visit_link(element);
+		end
+	end
+
 	def visit_text(element)
 		output << CGI.escapeHTML(element.text)
 	end
@@ -162,6 +180,18 @@ protected
 	def header2name(str)
 		'label' + encode64(str.strip).chomp().tr('+=', '__');
 	end
+
+	def inter_wiki_name_table
+		unless @inter_wiki_name_table then
+			@inter_wiki_name_table  = {}
+			if self.inter_wiki_name_document then
+				analyzer = InterWikiNameAnalyzer::new(@inter_wiki_name_table);
+				self.inter_wiki_name_document.accept(analyzer);
+			end
+		end
+		@inter_wiki_name_table
+	end
+
 end
 
 end
